@@ -45,7 +45,7 @@
 /*****************************************************************************
  * Private functions
  *****************************************************************************/
-static void print_usage();
+static void print_usage (FILE* stream);
 static void print_status (RIP_MANAGER_INFO *rmi);
 static void catch_sig (int code);
 static void parse_arguments (STREAM_PREFS *prefs, int argc, char **argv);
@@ -85,13 +85,14 @@ main (int argc, char *argv[])
     STREAM_PREFS prefs;
     RIP_MANAGER_INFO *rmi = 0;
 
+    sr_set_locale ();
+
     signal (SIGINT, catch_sig);
     signal (SIGTERM, catch_sig);
 
     parse_arguments (&prefs, argc, argv);
 
     print_to_console ("Connecting...\n");
-
     
     rip_manager_init ();
 
@@ -265,55 +266,57 @@ rip_callback (RIP_MANAGER_INFO* rmi, int message, void *data)
     }
 }
 
+/* Usage should be printed to stdout when it is not an error 
+   http://www.gnu.org/prep/standards/standards.html */
 static void
-print_usage()
+print_usage (FILE* stream)
 {
-    fprintf(stderr, "Usage: streamripper URL [OPTIONS]\n");
-    fprintf(stderr, "Opts: -h             - Print this listing\n");
-    fprintf(stderr, "      -v             - Print version info and quit\n");
-    fprintf(stderr, "      -a [file]      - Rip to single file, default name is timestamped\n");
-    fprintf(stderr, "      -A             - Don't write individual tracks\n");
-    fprintf(stderr, "      -d dir         - The destination directory\n");
-    fprintf(stderr, "      -D pattern     - Write files using specified pattern\n");
-    fprintf(stderr, "      -s             - Don't create a directory for each stream\n");
-    fprintf(stderr, "      -r [[ip:]port] - Create relay server on base ip:port, default port 8000\n");
-    fprintf(stderr, "      -R #connect    - Max connections to relay, default 1, -R 0 is no limit\n");
-    fprintf(stderr, "      -L file        - Create a relay playlist file\n");
-    fprintf(stderr, "      -z             - Don't scan for free ports if base port is not avail\n");
-    fprintf(stderr, "      -p url         - Use HTTP proxy server at <url>\n");
-    fprintf(stderr, "      -o (always|never|larger)    - When to tracks in complete\n");
-    fprintf(stderr, "      -t             - Don't overwrite tracks in incomplete\n");
-    fprintf(stderr, "      -c             - Don't auto-reconnect\n");
-    fprintf(stderr, "      -l seconds     - Number of seconds to run, otherwise runs forever\n");
-    fprintf(stderr, "      -M megabytes   - Stop ripping after this many megabytes\n");
-    fprintf(stderr, "      -q [start]     - Add sequence number to output file\n");
-    fprintf(stderr, "      -u useragent   - Use a different UserAgent than \"Streamripper\"\n");
-    fprintf(stderr, "      -w rulefile    - Parse metadata using rules in file.\n");
-    fprintf(stderr, "      -m timeout     - Number of seconds before force-closing stalled conn\n");
-    fprintf(stderr, "      -k count       - Leave <count> tracks in incomplete\n");
+    fprintf(stream, "Usage: streamripper URL [OPTIONS]\n");
+    fprintf(stream, "Opts: -h             - Print this listing\n");
+    fprintf(stream, "      -v             - Print version info and quit\n");
+    fprintf(stream, "      -a [file]      - Rip to single file, default name is timestamped\n");
+    fprintf(stream, "      -A             - Don't write individual tracks\n");
+    fprintf(stream, "      -d dir         - The destination directory\n");
+    fprintf(stream, "      -D pattern     - Write files using specified pattern\n");
+    fprintf(stream, "      -s             - Don't create a directory for each stream\n");
+    fprintf(stream, "      -r [[ip:]port] - Create relay server on base ip:port, default port 8000\n");
+    fprintf(stream, "      -R #connect    - Max connections to relay, default 1, -R 0 is no limit\n");
+    fprintf(stream, "      -L file        - Create a relay playlist file\n");
+    fprintf(stream, "      -z             - Don't scan for free ports if base port is not avail\n");
+    fprintf(stream, "      -p url         - Use HTTP proxy server at <url>\n");
+    fprintf(stream, "      -o (always|never|larger|version)    - When to tracks in complete\n");
+    fprintf(stream, "      -t             - Don't overwrite tracks in incomplete\n");
+    fprintf(stream, "      -c             - Don't auto-reconnect\n");
+    fprintf(stream, "      -l seconds     - Number of seconds to run, otherwise runs forever\n");
+    fprintf(stream, "      -M megabytes   - Stop ripping after this many megabytes\n");
+    fprintf(stream, "      -q [start]     - Add sequence number to output file\n");
+    fprintf(stream, "      -u useragent   - Use a different UserAgent than \"Streamripper\"\n");
+    fprintf(stream, "      -w rulefile    - Parse metadata using rules in file.\n");
+    fprintf(stream, "      -m timeout     - Number of seconds before force-closing stalled conn\n");
+    fprintf(stream, "      -k count       - Leave <count> tracks in incomplete\n");
 #if !defined (WIN32)
-    fprintf(stderr, "      -I interface   - Rip from specified interface (e.g. eth0)\n");
+    fprintf(stream, "      -I interface   - Rip from specified interface (e.g. eth0)\n");
 #endif
-    fprintf(stderr, "      -T             - Truncate duplicated tracks in incomplete\n");
-    fprintf(stderr, "      -E command     - Run external command to fetch metadata\n");
-    fprintf(stderr, "      --quiet        - Don't print ripping status to console\n");
-    fprintf(stderr, "      --stderr       - Print ripping status to stderr (old behavior)\n");
-    fprintf(stderr, "      --debug        - Save debugging trace\n");
-    fprintf(stderr, "ID3 opts (mp3/aac/nsv):  [The default behavior is adding ID3V2.3 only]\n");
-    fprintf(stderr, "      -i                           - Don't add any ID3 tags to output file\n");
-    fprintf(stderr, "      --with-id3v1                 - Add ID3V1 tags to output file\n");
-    fprintf(stderr, "      --without-id3v2              - Don't add ID3V2 tags to output file\n");
-    fprintf(stderr, "Splitpoint opts (mp3 only):\n");
-    fprintf(stderr, "      --xs2                        - Use new algorithm for silence detection\n");
-    fprintf(stderr, "      --xs-offset=num              - Shift relative to metadata (msec)\n");
-    fprintf(stderr, "      --xs-padding=num:num         - Add extra to prev:next track (msec)\n");
-    fprintf(stderr, "      --xs-search-window=num:num   - Search window relative to metadata (msec)\n");
-    fprintf(stderr, "      --xs-silence-length=num      - Expected length of silence (msec)\n");
-    fprintf(stderr, "Codeset opts:\n");
-    fprintf(stderr, "      --codeset-filesys=codeset    - Specify codeset for the file system\n");
-    fprintf(stderr, "      --codeset-id3=codeset        - Specify codeset for id3 tags\n");
-    fprintf(stderr, "      --codeset-metadata=codeset   - Specify codeset for metadata\n");
-    fprintf(stderr, "      --codeset-relay=codeset      - Specify codeset for the relay stream\n");
+    fprintf(stream, "      -T             - Truncate duplicated tracks in incomplete\n");
+    fprintf(stream, "      -E command     - Run external command to fetch metadata\n");
+    fprintf(stream, "      --quiet        - Don't print ripping status to console\n");
+    fprintf(stream, "      --stderr       - Print ripping status to stderr (old behavior)\n");
+    fprintf(stream, "      --debug        - Save debugging trace\n");
+    fprintf(stream, "ID3 opts (mp3/aac/nsv):  [The default behavior is adding ID3V2.3 only]\n");
+    fprintf(stream, "      -i                           - Don't add any ID3 tags to output file\n");
+    fprintf(stream, "      --with-id3v1                 - Add ID3V1 tags to output file\n");
+    fprintf(stream, "      --without-id3v2              - Don't add ID3V2 tags to output file\n");
+    fprintf(stream, "Splitpoint opts (mp3 only):\n");
+    fprintf(stream, "      --xs2                        - Use new algorithm for silence detection\n");
+    fprintf(stream, "      --xs-offset=num              - Shift relative to metadata (msec)\n");
+    fprintf(stream, "      --xs-padding=num:num         - Add extra to prev:next track (msec)\n");
+    fprintf(stream, "      --xs-search-window=num:num   - Search window relative to metadata (msec)\n");
+    fprintf(stream, "      --xs-silence-length=num      - Expected length of silence (msec)\n");
+    fprintf(stream, "Codeset opts:\n");
+    fprintf(stream, "      --codeset-filesys=codeset    - Specify codeset for the file system\n");
+    fprintf(stream, "      --codeset-id3=codeset        - Specify codeset for id3 tags\n");
+    fprintf(stream, "      --codeset-metadata=codeset   - Specify codeset for metadata\n");
+    fprintf(stream, "      --codeset-relay=codeset      - Specify codeset for the relay stream\n");
 }
 
 /* 
@@ -329,7 +332,7 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
     char *c;
 
     if (argc < 2) {
-	print_usage();
+	print_usage (stdout);
 	exit(2);
     }
 
@@ -357,7 +360,7 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
 	{
 	case 'a':
 	    /* Create single file output + cue sheet */
-	    prefs->flags |= OPT_SINGLE_FILE_OUTPUT;
+	    OPT_FLAG_SET (prefs->flags, OPT_SINGLE_FILE_OUTPUT, 1);
 	    prefs->showfile_pattern[0] = 0;
 	    if (i == (argc-1) || argv[i+1][0] == '-')
 		break;
@@ -365,10 +368,10 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
 	    strncpy (prefs->showfile_pattern, argv[i], SR_MAX_PATH);
 	    break;
 	case 'A':
-	    prefs->flags |= OPT_INDIVIDUAL_TRACKS;
+	    OPT_FLAG_SET (prefs->flags, OPT_INDIVIDUAL_TRACKS, 0);
 	    break;
 	case 'c':
-	    prefs->flags |= OPT_AUTO_RECONNECT;
+	    OPT_FLAG_SET (prefs->flags, OPT_AUTO_RECONNECT, 0);
 	    break;
 	case 'd':
 	    i++;
@@ -379,22 +382,22 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
 	    strncpy(prefs->output_pattern, argv[i], SR_MAX_PATH);
 	    break;
 	case 'E':
-	    prefs->flags |= OPT_EXTERNAL_CMD;
+	    OPT_FLAG_SET (prefs->flags, OPT_EXTERNAL_CMD, 1);
 	    i++;
 	    strncpy(prefs->ext_cmd, argv[i], SR_MAX_PATH);
 	    break;
 	case 'f':
 	    i++;
-	    printf ("Error: -f dropstring option is obsolete. "
-		    "Please use -w parse_rules instead.\n");
+	    fprintf (stderr, "Error: -f dropstring option is obsolete. "
+		     "Please use -w parse_rules instead.\n");
 	    exit (1);
 	case 'h':
-	    print_usage();
+	    print_usage (stdout);
             exit(0);
 	    break;
 	case 'i':
-	    OPT_FLAG_SET(prefs->flags,OPT_ADD_ID3V1,0);
-	    OPT_FLAG_SET(prefs->flags,OPT_ADD_ID3V2,0);
+	    OPT_FLAG_SET(prefs->flags, OPT_ADD_ID3V1, 0);
+	    OPT_FLAG_SET(prefs->flags, OPT_ADD_ID3V2, 0);
 	    break;
 	case 'I':
 	    i++;
@@ -420,14 +423,13 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
  	case 'M':
  	    i++;
  	    prefs->maxMB_rip_size = atoi(argv[i]);
- 	    prefs->flags |= OPT_CHECK_MAX_BYTES;
+	    OPT_FLAG_SET(prefs->flags, OPT_CHECK_MAX_BYTES, 1);
  	    break;
 	case 'o':
 	    i++;
 	    prefs->overwrite = string_to_overwrite_opt (argv[i]);
 	    if (prefs->overwrite == OVERWRITE_UNKNOWN) {
-		printf ("Error: -o option requires an argument\n"
-			"Please use \"-o always\" or \"-o never\"\n");
+		fprintf (stderr, "Error: -o option requires an argument\n");
 		exit (1);
 	    }
 	    break;
@@ -437,11 +439,11 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
 	    break;
 	case 'P':
 	    i++;
-	    printf ("Error: -P prefix option is obsolete. "
-		    "Please use -D pattern instead.\n");
+	    fprintf (stderr, "Error: -P prefix option is obsolete. "
+		     "Please use -D pattern instead.\n");
 	    exit (1);
 	case 'q':
-	    prefs->flags |= OPT_COUNT_FILES;
+	    OPT_FLAG_SET(prefs->flags, OPT_COUNT_FILES, 1);
 	    prefs->count_start = -1;     /* -1 means auto-detect */
 	    if (i == (argc-1) || argv[i+1][0] == '-')
 		break;
@@ -449,7 +451,7 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
 	    prefs->count_start = atoi(argv[i]);
 	    break;
 	case 'r':
-	    prefs->flags |= OPT_MAKE_RELAY;
+	    OPT_FLAG_SET(prefs->flags, OPT_MAKE_RELAY, 1);
 	    if (i == (argc-1) || argv[i+1][0] == '-')
 		break;
 	    i++;
@@ -467,13 +469,13 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
 	    prefs->max_connections = atoi(argv[i]);
 	    break;
 	case 's':
-	    prefs->flags |= OPT_SEPERATE_DIRS;
+	    OPT_FLAG_SET(prefs->flags, OPT_SEPARATE_DIRS, 0);
 	    break;
 	case 't':
-	    prefs->flags |= OPT_KEEP_INCOMPLETE;
+	    OPT_FLAG_SET(prefs->flags, OPT_KEEP_INCOMPLETE, 1);
 	    break;
 	case 'T':
-	    prefs->flags |= OPT_TRUNCATE_DUPS;
+	    OPT_FLAG_SET(prefs->flags, OPT_TRUNCATE_DUPS, 1);
 	    break;
 	case 'u':
 	    i++;
@@ -487,7 +489,7 @@ parse_arguments (STREAM_PREFS* prefs, int argc, char **argv)
 	    strncpy(prefs->rules_file, argv[i], SR_MAX_PATH);
 	    break;
 	case 'z':
-	    prefs->flags |= OPT_SEARCH_PORTS;
+	    OPT_FLAG_SET(prefs->flags, OPT_SEARCH_PORTS, 0);
 	    prefs->max_port = prefs->relay_port+1000;
 	    break;
 	case '-':
