@@ -404,6 +404,7 @@ mkdir_if_needed (RIP_MANAGER_INFO* rmi, gchar *str)
 {
     char s[SR_MAX_PATH];
     string_from_mstring (rmi, s, SR_MAX_PATH, str, CODESET_FILESYS);
+    debug_printf ("mkdir = %s -> %s\n", str, s);
 #if WIN32
     mkdir (s);
 #else
@@ -1252,15 +1253,13 @@ filelib_open_showfiles (RIP_MANAGER_INFO* rmi)
 			      m_(".cue"));
     if (new_show_name && new_cue_name) {
 	/* Rewrite previous cue file to point to renamed mp3 showfile */
-	printf ("Trying to adjust cuefile\n");
+	debug_printf ("Trying to adjust cuefile\n");
 	filelib_adjust_cuefile (rmi, new_show_name, new_cue_name);
     }
-    printf ("Trying to free\n");
     if (new_show_name) g_free (new_show_name);
     if (new_cue_name) g_free (new_cue_name);
     g_free (new_dir);
     g_free (new_fnbase);
-    printf ("Done.\n");
 
     /* Open cue file */
     rc = filelib_open_for_write (rmi, &fli->m_cue_file, fli->m_cue_name);
