@@ -148,7 +148,8 @@ http_parse_url(const char *url, URLINFO *urlinfo)
 
     /* search for a login '@' token */
     if (strchr(url, '@') != NULL) {
-	ret = sscanf(url, "%[^:]:%[^@]", urlinfo->username, urlinfo->password);
+	ret = sscanf(url, "%1023[^:]:%1023[^@]", 
+		     urlinfo->username, urlinfo->password);
 	if (ret < 1) {
 	    return SR_ERROR_PARSE_FAILURE;
 	} else if (ret == 1) {
@@ -169,14 +170,14 @@ http_parse_url(const char *url, URLINFO *urlinfo)
     /* search for a port seperator */
     if (strchr(url, ':') != NULL) {
 	debug_printf ("Branch 1 (%s)\n", url);
-	ret = sscanf(url, "%[^:]:%hu/%s", urlinfo->host, 
+	ret = sscanf(url, "%511[^:]:%hu/%252s", urlinfo->host, 
 		     (short unsigned int*)&urlinfo->port, urlinfo->path+1);
 	if (urlinfo->port < 1) return SR_ERROR_PARSE_FAILURE;
 	ret -= 1;
     } else {
 	debug_printf ("Branch 2 (%s)\n", url);
 	urlinfo->port = 80;
-	ret = sscanf(url, "%[^/]/%s", urlinfo->host, urlinfo->path+1);
+	ret = sscanf(url, "%511[^/]/%252s", urlinfo->host, urlinfo->path+1);
     }
     if (ret < 1) return SR_ERROR_INVALID_URL;
 
@@ -201,6 +202,8 @@ http_construct_sc_request(const char *url, const char* proxyurl, char *buffer, c
 	strcpy(myurl, ui.path);
     }
 
+#if defined (commentout)
+    /* This is the old header */
     snprintf(buffer, MAX_HEADER_LEN + MAX_HOST_LEN + SR_MAX_PATH,
 	     "GET %s HTTP/1.0\r\n"
 	     "Host: %s:%d\r\n"
@@ -210,6 +213,21 @@ http_construct_sc_request(const char *url, const char* proxyurl, char *buffer, c
 	     ui.host, 
 	     ui.port, 
 	     useragent[0] ? useragent : "Streamripper/1.x");
+#endif
+
+    /* This is the header suggested Florian Stoehr */
+    snprintf(buffer, MAX_HEADER_LEN + MAX_HOST_LEN + SR_MAX_PATH,
+	     "GET %s HTTP/1.1\r\n"
+	     "Accept: */*\r\n"
+	     "Cache-Control: no-cache\r\n"
+	     "User-Agent: %s\r\n"
+	     "Icy-Metadata: 1\r\n"
+	     "Connection: close\r\n"
+	     "Host: %s:%d\r\n",
+	     myurl,
+	     useragent[0] ? useragent: "Streamripper/1.x",
+	     ui.host,
+	     ui.port);
 
     // http authentication (not proxy, see below for that)
     if (ui.username[0] && ui.password[0]) {
@@ -466,6 +484,7 @@ http_parse_sc_header (const char *url, char *header, SR_HTTP_HEADER *info)
 	    info->content_type = content_type_by_url;
 	}
     }
+
     // Check for Icecast 1
     else if ((start = (char *)strstr(header, "icecast")) != NULL) {
 	if (!info->server[0]) {
@@ -491,7 +510,6 @@ http_parse_sc_header (const char *url, char *header, SR_HTTP_HEADER *info)
 	}
     }
 
-
     // Check for Apache
     else if (((start = (char *)strstr(header, "Apache")) != NULL) &&
 	     ((start = (char *)strstr(header, "x-audiocast-name")) != NULL)) {
@@ -510,11 +528,6 @@ http_parse_sc_header (const char *url, char *header, SR_HTTP_HEADER *info)
 	}
     }
 
-    // WTF is Zwitterion?
-    else if ((start = (char *)strstr(header, "Zwitterion v")) != NULL) {
-	sscanf(start, "%[^<]<", info->server);
-    }
-
     /* Last chance to deduce content type */
     if (info->content_type == CONTENT_TYPE_UNKNOWN) {
 	if (content_type_by_url == CONTENT_TYPE_UNKNOWN) {
@@ -714,7 +727,7 @@ http_get_pls (RIP_MANAGER_INFO* rmi, HSOCKET *sock, SR_HTTP_HEADER *info)
 	    break;
 	}
 	if (s == 1) {
-	    strcpy (info->http_location, location_buf);
+	    sr_strncpy (info->http_location, location_buf, MAX_HOST_LEN);
 	    rc = SR_SUCCESS;
 	}
 	
@@ -728,12 +741,12 @@ http_get_pls (RIP_MANAGER_INFO* rmi, HSOCKET *sock, SR_HTTP_HEADER *info)
 	}
 	open = total - used;
 	if (open > best_open) {
-	    strcpy (info->http_location, location_buf);
+	    sr_strncpy (info->http_location, location_buf, MAX_HOST_LEN);
 	    best_open = open;
 	}
     }
 
-    strcpy (info->http_location, location_buf);
+    sr_strncpy (info->http_location, location_buf, MAX_HOST_LEN);
 
     return rc;
 }
@@ -773,7 +786,7 @@ http_get_m3u (RIP_MANAGER_INFO* rmi, HSOCKET *sock, SR_HTTP_HEADER *info)
 	if (len > 4 && !strcmp (&p[len-4], ".mp3")) {
 	    continue;
 	}
-	strcpy (info->http_location, p);
+	sr_strncpy (info->http_location, p, MAX_HOST_LEN);
 	debug_printf ("Redirecting from M3U to: %s\n", p);
 	return SR_SUCCESS;
     }
