@@ -100,11 +100,21 @@ prefs_load (void)
     debug_printf ("prefs_fn [utf8] = %s\n", prefs_fn);
 
     if (!m_key_file) {
+	debug_printf ("Trying g_key_file_new()...\n");
 	m_key_file = g_key_file_new ();
+	if (!m_key_file) {
+	    debug_printf ("Error creating key file with g_key_file_new()\n");
+	}
     }
     flags = G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS;
     rc = g_key_file_load_from_file (m_key_file, prefs_fn,
 				    flags, &error);
+    debug_printf ("g_key_file_load_from_file returned %d\n", rc);
+    if (error) {
+	debug_printf ("Error with g_key_file_load_from_data: %s\n",
+		error->message);
+	g_error_free (error);
+    }
 
     /* Make sure a full set of global preferences are created in keyfile */
     prefs_get_global_prefs (&global_prefs);
@@ -112,6 +122,7 @@ prefs_load (void)
 
     /* Silently update preferences on version change */
     if (rc) {
+	int rc1;
 	u_long dropcount;
 	char overwrite_str[128];
 
@@ -120,16 +131,16 @@ prefs_load (void)
 	switch (string_to_prefs_version (global_prefs.version)) {
 	case PREFS_VERSION_1_63_BETA_2:
 	    /* Silently update dropcount */
-	    rc = prefs_get_ulong (&dropcount, "stream defaults", "dropcount");
-	    if (!rc || dropcount == 0) {
+	    rc1 = prefs_get_ulong (&dropcount, "stream defaults", "dropcount");
+	    if (!rc1 || dropcount == 0) {
 		prefs_set_integer ("stream defaults", "dropcount", 1);
 	    }
 	    /* Fall through */
 	case PREFS_VERSION_1_63_BETA_8:
 	    /* Silently update overwrite behavior */
-	    rc = prefs_get_string (overwrite_str, 128, "stream defaults",
+	    rc1 = prefs_get_string (overwrite_str, 128, "stream defaults",
 				   "over_write_complete");
-	    if (!rc || !strcmp (overwrite_str, "larger")) {
+	    if (!rc1 || !strcmp (overwrite_str, "larger")) {
 		prefs_set_string ("stream defaults", "over_write_complete", 
 				  "version");
 	    }
@@ -159,6 +170,7 @@ prefs_save (void)
     gchar* keyfile_contents;
     gsize keyfile_contents_len;
 
+    debug_printf ("Saving preferences.\n");
     prefs_dir = prefs_get_config_dir ();
     if (g_mkdir_with_parents (prefs_dir, 0755)) {
 	debug_printf ("Couldn't make config dir: %s\n", prefs_dir);
@@ -170,6 +182,7 @@ prefs_save (void)
 				 "streamripper.ini",
 				 NULL);
     g_free (prefs_dir);
+    debug_printf ("Filename: %s\n", prefs_fn);
 
     /* Insert from prefs into keyfile */
     // prefs_copy_to_keyfile (prefs);
@@ -179,7 +192,9 @@ prefs_save (void)
 					   &keyfile_contents_len, 
 					   &error);
     if (error) {
-	debug_printf ("Error with g_key_file_to_data\n");
+	debug_printf ("Error with g_key_file_to_data: %s\n",
+		error->message);
+	g_error_free (error);
 	g_free (prefs_fn);
 	return;
     }
@@ -189,8 +204,11 @@ prefs_save (void)
 	rather than --codeset-filesys here. */
     fp = g_fopen (prefs_fn, "w");
     if (fp) {
+	debug_printf ("Writing, len = %d\n", keyfile_contents_len);
 	fwrite (keyfile_contents, 1, keyfile_contents_len, fp);
 	fclose (fp);
+    } else {
+	debug_printf ("Error opening prefs file for write\n");
     }
     g_free (keyfile_contents);
     g_free (prefs_fn);
@@ -502,6 +520,7 @@ prefs_get_string (char* dest, gsize dest_size, char* group, char* key)
     value = g_key_file_get_string (m_key_file, group, key, &error);
     if (error) {
 	/* Key doesn't exist, do nothing */
+	g_error_free (error);
 	return 0;
     }
     if (g_strlcpy (dest, value, dest_size) >= dest_size) {
@@ -520,7 +539,7 @@ prefs_get_ushort (u_short *dest, char *group, char *key)
     value = g_key_file_get_integer (m_key_file, group, key, &error);
     if (error) {
 	/* Key doesn't exist, do nothing */
-	// g_error (error->message);
+	g_error_free (error);
 	return;
     }
     if (value < 0 || value > G_MAXUSHORT) {
@@ -540,6 +559,7 @@ prefs_get_ulong (u_long *dest, char *group, char *key)
     value = g_key_file_get_integer (m_key_file, group, key, &error);
     if (error) {
 	/* Key doesn't exist, do nothing */
+	g_error_free (error);
 	return 0;
     }
     if (value < 0) {
@@ -559,6 +579,7 @@ prefs_get_long (long *dest, char *group, char *key)
     value = g_key_file_get_integer (m_key_file, group, key, &error);
     if (error) {
 	/* Key doesn't exist, do nothing */
+	g_error_free (error);
 	return;
     }
     *dest = (long) value;
@@ -573,6 +594,7 @@ prefs_get_int (int *dest, char *group, char *key)
     value = g_key_file_get_integer (m_key_file, group, key, &error);
     if (error) {
 	/* Key doesn't exist, do nothing */
+	g_error_free (error);
 	return;
     }
     *dest = (u_long) value;
