@@ -63,31 +63,19 @@ socklib_init()
     WORD wVersionRequested;
     WSADATA wsaData;
     int err;
-#endif
 
-#if defined (commentout)
-    if (m_done_init)
-	return SR_SUCCESS;
-#endif
-
-#if WIN32
     wVersionRequested = MAKEWORD( 2, 2 );
     err = WSAStartup( wVersionRequested, &wsaData );
     if ( err != 0 )
         return SR_ERROR_WIN32_INIT_FAILURE;
 #endif
 
-#if defined (commentout)
-    m_done_init = TRUE;
-#endif
-
     return SR_SUCCESS;
 }
 
-
 /* Try to find the local interface to bind to */
 error_code
-read_interface(char *if_name, uint32_t *addr)
+read_interface (char *if_name, uint32_t *addr)
 {
 #if defined (WIN32)
     return -1;
@@ -138,7 +126,7 @@ socklib_open(HSOCKET *socket_handle, char *host, int port, char *if_name)
     }
 
     if (if_name) {
-	if (read_interface(if_name,&local.sin_addr.s_addr) != 0)
+	if (read_interface (if_name, &local.sin_addr.s_addr) != 0)
 	    local.sin_addr.s_addr = htonl(INADDR_ANY);
 	local.sin_family = AF_INET;
 	local.sin_port = htons(0);
@@ -202,9 +190,6 @@ void
 socklib_cleanup()
 {
     WSACleanup();
-#if defined (commentout)
-    m_done_init = FALSE;
-#endif
 }
 
 void
